==> google-cloud-aiplatform-1.10.0-py38haa244fe_0.tar.bz2: Lib/site-packages/google/cloud/aiplatform/v1/schema/predict/instance_v1/types/image_object_detection.py <==
# -*- coding: utf-8 -*-
# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
import proto  # type: ignore


__protobuf__ = proto.module(
    package="google.cloud.aiplatform.v1.schema.predict.instance",
    manifest={"ImageObjectDetectionPredictionInstance",},
)


class ImageObjectDetectionPredictionInstance(proto.Message):
    r"""Prediction input format for Image Object Detection.

    Attributes:
        content (str):
            The image bytes or Cloud Storage URI to make
            the prediction on.
        mime_type (str):
            The MIME type of the content of the image.
            Only the images in below listed MIME types are
            supported. - image/jpeg
            - image/gif
            - image/png
            - image/webp
            - image/bmp
            - image/tiff
            - image/vnd.microsoft.icon
    """

    content = proto.Field(proto.STRING, number=1,)
    mime_type = proto.Field(proto.STRING, number=2,)


__all__ = tuple(sorted(__protobuf__.manifest))

==> google-cloud-aiplatform-1.13.0-py38haa244fe_0.tar.bz2: Lib/site-packages/google/cloud/aiplatform/v1/schema/predict/instance_v1/types/image_object_detection.py <==
# -*- coding: utf-8 -*-
# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
import proto  # type: ignore


__protobuf__ = proto.module(
    package="google.cloud.aiplatform.v1.schema.predict.instance",
    manifest={
        "ImageObjectDetectionPredictionInstance",
    },
)


class ImageObjectDetectionPredictionInstance(proto.Message):
    r"""Prediction input format for Image Object Detection.

    Attributes:
        content (str):
            The image bytes or Cloud Storage URI to make
            the prediction on.
        mime_type (str):
            The MIME type of the content of the image.
            Only the images in below listed MIME types are
            supported. - image/jpeg
            - image/gif
            - image/png
            - image/webp
            - image/bmp
            - image/tiff
            - image/vnd.microsoft.icon
    """

    content = proto.Field(
        proto.STRING,
        number=1,
    )
    mime_type = proto.Field(
        proto.STRING,
        number=2,
    )


__all__ = tuple(sorted(__protobuf__.manifest))
